package com.winhc.returnmoney.aspect;
import com.winhc.common.util.GSON;
import com.winhc.returnmoney.model.bo.AspectRequestBO;
import com.winhc.returnmoney.util.MethodControlUtil;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;


/**
 * @description: 日志切面
 * @author: yujie
 * @date 2019.11.27 8:52
 */
@Order
@Slf4j
@Aspect
@Component
public class LogAspect {

    private static final String SEP = "\n";
    private static String context_format = null;
    private static String context_response = null;

    static {
        context_format = SEP + "->->->->->->->->->->->->->->->->->->->->->->->->->->->->" + SEP;
        context_format += "-> {}" + SEP;
        context_format += "-> Target: class[{}],method[{}]" + SEP;
        context_format += "-> Url: path[{}],method[{}]" + SEP;
        context_format += "-> Parameters : {} " + SEP;
        context_format += "->->->->->->->->->->->->->->->->->->->->->->->->->->->->" + SEP;

        context_response = SEP + "<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-" + SEP;
        context_response += "<- Response:{}" + SEP;
        context_response += "<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-<-" + SEP;
    }

    @Before("@annotation(apiOperation)")
    public void doBefore(JoinPoint joinPoint, ApiOperation apiOperation) throws Throwable {
        Signature signature = joinPoint.getSignature();
        String methodName = signature.getName();
        MethodSignature methodSignature = (MethodSignature) signature;
        String className = signature.getDeclaringTypeName();
        // 获取请求方式信息
        AspectRequestBO aspectRequestBO = MethodControlUtil.getMethod(signature);
        // 获取请求参数
        String requestString = "void";
        Object[] parameters = joinPoint.getArgs();
        if (signature.toShortString().contains("..")) {
            String[] parameterNames = methodSignature.getParameterNames();
            StringBuilder reBuilder = new StringBuilder();
            for (int index = 0; index < parameterNames.length; ++index) {
                if (parameters[index] instanceof HttpServletResponse) {
                    continue;
                }
                reBuilder.append(parameterNames[index]).append("=").append(GSON.toJSON(parameters[index])).append(";");
            }
            requestString = reBuilder.toString();
        }
        log.info(context_format, aspectRequestBO.getDesc(),className,methodName, aspectRequestBO.getPath(), aspectRequestBO.getMethod(),requestString);
    }

    @AfterReturning(returning = "cvt",pointcut = "@annotation(org.springframework.web.bind.annotation.ResponseBody)")
    public void doAfterException(JoinPoint joinPoint, Object cvt){
        log.info(context_response,getResponse(cvt));
    }

    @AfterReturning(returning = "cvt",pointcut = "@annotation(io.swagger.annotations.ApiOperation)")
    public void doAfter(JoinPoint joinPoint, Object cvt){
        log.info(context_response,getResponse(cvt));
    }

    private String getResponse(Object cvt) {
        String res = "void";
        if (cvt != null) {
            res = GSON.toJSON(cvt);
        }
        return res;
    }
}
