package com.winhc.returnmoney.model.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.winhc.returnmoney.common.Constant;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.hibernate.validator.constraints.Range;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

/**
 * @description AccountBook DTO对象
 * @author Generator
 * @date 2020-12-15
 */
@Data
@ApiModel(value="新增账本")
public class AddAccountBillDTO {

    @ApiModelProperty(value = "账本id,不传则表示新建一个账款+账本")
    private Long accountBookId;

    @ApiModelProperty(value = "收款公司名称")
    @Length(max = 20, message = "收款公司名称超出长度限制")
    private String payeeName;

    @ApiModelProperty(value = "付款公司cid列表(移除)")
    @Deprecated
    private List<String> payerCidList;

    @ApiModelProperty(value = "付款公司companyId列表(新增)")
    private List<String> payerCompanyIdList;

    @ApiModelProperty(value = "总应收金额")
    @NotNull(message = "应收金额不能为空")
    @DecimalMax(value = Constant.MAX_MONEY, message = "应收金额超出限制")
    @DecimalMin(value = "0", message = "应收金额低于限制")
    private BigDecimal receivable;

    @ApiModelProperty(value = "账款状态，1进行中，2已逾期")
    @NotNull(message = "账款状态不能为空")
    @Range(min = 1, max = 2, message = "账款状态选择错误")
    private Integer accountBillStatus;

    @ApiModelProperty(value = "账款阶段，1未起诉，2已起诉，3已申请执行，4终结本次执行")
    @Range(min = 1, max = 4, message = "账款阶段选择错误")
    private Integer accountBillStage;

    @ApiModelProperty(value = "应收账款日期, string, 格式yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private LocalDate endDate;

    @ApiModelProperty(value = "账款备注")
    @Length(max = 7, message = "备注超过长度限制")
    private String accountBillRemark;







}
