package com.winhc.returnmoney.model.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.winhc.returnmoney.common.Constant;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;
import org.hibernate.validator.constraints.Range;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.DecimalMax;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.util.List;

/**
 * @Description: UpdateAccountBillDTO
 * @Author: xda
 * @Date: 2020/12/17  14:27
 */
@Data
@ApiModel("修改账款信息对象")
@Accessors(chain = true)
public class UpdateAccountBillDTO {

    @ApiModelProperty(hidden = true)
    private Long userId;

    @ApiModelProperty("修改类型：1修改账款日期，2修改账款应收金额(新版本不再支持)，3修改整个账款信息")
    @Range(min = 1, max = 3, message = "修改类型错误")
    @NotNull(message = "修改类型不能为空")
    private Integer type;

    @ApiModelProperty(hidden = true)
    private Long accountBillId;

    @ApiModelProperty("应收日期,字符串格式yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private LocalDate endDate;

    @ApiModelProperty(value = "应收金额")
    @DecimalMax(value = Constant.MAX_MONEY, message = "应收金额超出限制")
    @DecimalMin(value = "0", message = "应收金额低于限制")
    private BigDecimal receivable;

    @ApiModelProperty(value = "付款公司cid列表")
    @Deprecated
    private List<String> payerCidList;

    @ApiModelProperty(value = "付款公司companyId列表")
    private List<String> payerCompanyIdList;

    @ApiModelProperty(value = "账款状态，1进行中，2已逾期")
    @Range(min = 1, max = 2, message = "账款状态选择错误")
    private Integer accountBillStatus;

    @ApiModelProperty(value = "账款阶段，1未起诉，2已起诉，3已申请执行，4终结本次执行")
    @Range(min = 1, max = 4, message = "账款阶段选择错误")
    private Integer accountBillStage;

    @ApiModelProperty(value = "账款备注")
    @Length(max = 7, message = "备注超过长度限制")
    private String accountBillRemark;

}
