package com.winhc.returnmoney.model.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @Description: AccountBillVO
 * @Author: xda
 * @Date: 2020/12/16  13:39
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Accessors(chain = true)
public class AccountBillVO {

    private Long id;

    @ApiModelProperty(value = "账本id")
    private Long accountBookId;

    @ApiModelProperty(value = "当前应收金额")
    private BigDecimal receivable;

    @ApiModelProperty(value = "当前应收金额str")
    private String receivableStr;

    @ApiModelProperty(value = "账款状态，1进行中，2已逾期，3已收回")
    private Integer accountBillStatus;

    @ApiModelProperty(value = "账款阶段，1未起诉，2已起诉，3已申请执行，4终结本次执行")
    private Integer accountBillStage;

    @ApiModelProperty(value = "应收账款日期")
    private LocalDate endDate;

    @ApiModelProperty(value = "账款备注")
    private String accountBillRemark;

    @ApiModelProperty(value = "账款标题")
    private String accountBillTitle;

    @ApiModelProperty(value = "账款logo")
    private String accountBillLogo;

    @ApiModelProperty(value = "账款刷新状态。1未刷新，2刷新中，3已刷新，0刷新失败")
    private Integer refreshStatus;

    @ApiModelProperty(value = "上次评估ID")
    private Long preDiagnosisId;

    @ApiModelProperty(value = "评估id")
    private Long diagnosisId;

    @ApiModelProperty(value = "上次评估等级")
    private String preDiagnosisGrade;

    @ApiModelProperty(value = "评估等级")
    @TableField("DIAGNOSIS_GRADE")
    private String diagnosisGrade;

    @ApiModelProperty(value = "上次评估分数")
    private BigDecimal preDiagnosisScore;

    @ApiModelProperty(value = "本次评估分数")
    private BigDecimal diagnosisScore;

    @ApiModelProperty(value = "上次评估时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime preDiagnosisDatetime;

    @ApiModelProperty(value = "评估时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime diagnosisDatetime;

    @ApiModelProperty(value = "趋势，1上升，2下降。0持平")
    private Integer diagnosisTrend;

    @ApiModelProperty("提醒消息")
    private String remindInfo;

    @ApiModelProperty("userId")
    private Long userId;

    @ApiModelProperty(value = "是否删除，1删除。0否")
    private Integer deleted;

    @ApiModelProperty(value = "创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime timeCreated;

    @ApiModelProperty(value = "修改时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime timeModified;

    @ApiModelProperty("动态countList(新增)")
    private List<Integer> dynamicCountList;

    @ApiModelProperty("提醒描述(新增)")
    private String remindContent;

    @ApiModelProperty("动态时间,字符串,MM-dd or HH:mm(新增)")
    private String remindTimeStr;

    @ApiModelProperty(value = "本次评估分数趋势，1上升，2下降。0持平(新增)")
    private Integer diagnosisScoreTrend;

    @ApiModelProperty(value = "本次评估等级描述(新增)")
    private String diagnosisGradeDesc;

    @ApiModelProperty(value = "付款公司companyId(新增)")
    private String payerCompanyId;

    @ApiModelProperty(value = "账款总金额(新增)")
    private BigDecimal accountBillTotalMoney;

    @ApiModelProperty(value = "账款总金额(新增)")
    private String accountBillTotalMoneyStr;

    @ApiModelProperty(value = "已收回金额(新增)")
    private BigDecimal receiptMoney;

    @ApiModelProperty(value = "已收回金额(新增)")
    private String receiptMoneyStr;

    @ApiModelProperty("提醒id")
    private Long remindHistoryId;

    @ApiModelProperty("提醒标题")
    private String remindTitle;

    @ApiModelProperty("提醒类型,枚举(中文)：逾期提醒、账款评级、财产线索、风险预警")
    private String remindType;

    @ApiModelProperty("提醒日期,字符串,格式yyyy-MM-dd(移除)")
    private LocalDate remindDate;



}
