package com.winhc.returnmoney.util;

import com.alibaba.fastjson.JSON;
import com.winhc.returnmoney.cloud.bean.CompanyBasicVO;
import com.winhc.returnmoney.cloud.bean.ESCompany;
import com.winhc.returnmoney.entity.AccountBill;
import com.winhc.returnmoney.enums.Dict;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.time.LocalDate;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @Description: LogoUtil
 * @Author: xda
 * @Date: 2020/12/17  16:48
 */
public class AccountBookUtil {

    private static final Logger LOGGER = LoggerFactory.getLogger(AccountBookUtil.class);

    public static void convert2Logo(AccountBill accountBill, List<ESCompany> sortList) {
        // 转一下logo
        List<String> logoList = sortList.stream().map(ESCompany::getLogo).filter(StringUtils::isNotBlank).collect(Collectors.toList());
        String logoString;
        if (CollectionUtils.isNotEmpty(logoList) && logoList.size() > 4) {
            logoString = StringUtils.join(logoList.subList(0, 4).toArray(), ";");
        } else {
            logoString= StringUtils.join(logoList.toArray(), ";");
        }
        accountBill.setAccountBillLogo(logoString);
    }

    /**
     * 多个公司名转换
     * @param payerNameList payerNameList
     * @return java.lang.String
     * @Author: xda
     * @Date: 2020/12/17 09:54
     */
    public static String convertBillTitle(List<String> payerNameList) {
        LOGGER.info("转换公司名称:[{}]", JSON.toJSONString(payerNameList));
        if (CollectionUtils.isEmpty(payerNameList)) {
            return "";
        }
        if (payerNameList.size() == 1) {
            return payerNameList.get(0);
        }
        return String.format("%s%s%s%s", payerNameList.get(0), "等", payerNameList.size(), "家");
    }

    public static void convert2Company(List<ESCompany> sortList, Map<String, ESCompany> companyMap, List<String> cidList) {
        cidList.forEach(cid -> {
            if (companyMap.containsKey(cid)) {
                ESCompany company = new ESCompany();
                company.setId(cid);
                company.setQueryName(companyMap.get(cid).getQueryName());
                company.setLogo(companyMap.get(cid).getLogo());
                sortList.add(company);
            }
        });
    }

    public static void convert2CompanyBasic(List<CompanyBasicVO> sortList, Map<String, CompanyBasicVO> companyMap, List<String> companyIdList) {
        companyIdList.forEach(companyId -> {
            if (companyMap.containsKey(companyId)) {
                CompanyBasicVO vo = new CompanyBasicVO(companyId, companyMap.get(companyId).getCompanyName());
                sortList.add(vo);
            }
        });
    }

    public static Integer getAccountBillStatusCode(AccountBill accountBill) {
        if (Objects.isNull(accountBill.getEndDate())) {
            return accountBill.getAccountBillStatus();
        }
        if (LocalDate.now().isEqual(accountBill.getEndDate()) || LocalDate.now().isAfter(accountBill.getEndDate())) {
            return Dict.AccountBillStatusEnum.OVERDUE.getCode();
        }
        return Dict.AccountBillStatusEnum.PROGRESSING.getCode();
    }
}
